;+
; NAME:
;       READ_ANALIST
; PURPOSE:
;       Reads a list of files and frame indices created by the ANA Browser
; CATEGORY:
; CALLING SEQUENCE:
;       read_analist,analist_filename,files,dsets  [,filestr]
; INPUTS:
;	analist_filename	name of input list file
; OPTIONAL INPUT PARAMETERS:
; KEYWORD PARAMETERS:
; OUTPUTS:
;	files		list of files
;	dsets		datasets within the files
; OPTIONAL OUTPUT PARAMETERS:
;	filestr		structure containing file, dsets, week directory of
;			the file, and on-line status of the files
; COMMON BLOCKS:
; SIDE EFFECTS:
; RESTRICTIONS:
; PROCEDURE:
; MODIFICATION HISTORY:
;       RDB     Sep-98  Written
;
;-

pro	read_analist,filename,files,dsets,retstr

;	read the list prepared by ANA
qq=rd_tfile(filename,2)                    

fileid = qq(0,*)
nlines = n_elements(fileid)

break_file,fileid,aa,bb,cc,dd,ee 

;	only return the filenames, 
;	the directory information may refer to another site.
files = cc+dd
dsets = reform(fix(qq(1,*)))

print,' '
print,'Total number of images in file: ',nlines

if n_params() eq 4 then begin

;	make a structure in case we want it...
   fset = {week: ' ', file: ' ', dset: 0, online: 0}
   retstr = replicate(fset, nlines)

   weeks = strarr(nlines)
   for j=0,nlines-1 do begin
      bbx = str_sep(bb(j),'/')                                  
      weeks(j) = bbx(where(strpos(bbx,'week') ge 0))     
   endfor
   online = concat_dir('TRACE_I1_DIR',concat_dir(weeks,files))
   exist = file_exist(online)

   retstr.week = weeks
   retstr.file = files
   retstr.dset = dsets
   retstr.online = exist

endif

return
end
