;+
; NAME:
;	TRACE_SSWHERE
; PURPOSE:
;	Select subset of TRACE images with widget interface
; CATEGORY:
; CALLING SEQUENCE:
;	ss = trace_sswhere(index)
; INPUTS:
;	index	a TRACE index (or catalalog) structure
; OPTIONAL INPUT PARAMETERS:
; KEYWORD PARAMETERS:
;	debug	prints additional information if set
; OUTPUTS:
;	ss	a vector of selected records within the input structure
; OPTIONAL OUTPUT PARAMETERS:
; COMMON BLOCKS:
;	obs_tbl, obs_cms, obs_btn, obs_times
; SIDE EFFECTS:
; RESTRICTIONS:
;	Does not currently select the pointing
; PROCEDURE:
; MODIFICATION HISTORY:
;	RDB     Sep-98  Written
;
;-
function	trace_sswhere,index,debug=debug

common obs_tbl,bchans,hchans,schans,wchans,gchans,ggch,gghilo
common obs_cm2,bchan_vec,hchan_vec,schan_vec,wchan_vec,gchan_vec, $
		durn,batse,exact,fem,fov,sfm,quit
common obs_btnx,b0a,b0b,b1,b2,b2a,b2b,b2c,b3,b4,b5,duration
common obs_btn,timwgt,timwgt2,expmin,expmax,txtwgt,listwgt

common obs_times,time1,time2,texp1,texp2,wdebug
common obs_index,cat_index, dsets

wdebug=0
if keyword_set(debug) then wdebug=1

trace_sswhere_reset	;setup some values...


;	check this is a valid structure???

;	derive what ranges available
exposure   = gt_tagval(index,/sht_mdur,found=found)
wavelength = gt_tagval(index,/wave_len,found=found)
xcen       = gt_tagval(index,/xcen,found=found)
ycen       = gt_tagval(index,/ycen,found=found)
nx         = gt_tagval(index,/naxis1,found=found)
ny         = gt_tagval(index,/naxis2,found=found)
dx         = gt_tagval(index,/cdelt1,found=found)
dy         = gt_tagval(index,/cdelt2,found=found)
;help,index,nx,ny,dx

fmt_timer,index,time1,time2		;get time range

w_wave  = all_vals(wavelength)
w_exp   = all_vals(string(exposure,format='(f7.3)'))
w_xcen  = all_vals(xcen)
w_ycen  = all_vals(ycen)
w_nx    = all_vals(nx)
w_ny    = all_vals(ny)
w_dx    = all_vals(dx)

cat_index = index			;store in common
;;;dsets = index.image_ss		;default to all selected
dsets = indgen(n_elements(index))	;default to all selected

whole = widget_base(title='WOBS_PLOT',/column,/align_center)

;			control buttons at top
;	SHOULD this be a pull-down menu?
control = widget_base(whole,/row,/frame)
qq = widget_button(control,value='EXIT',uvalue='Exit',/frame)
qq = widget_button(control,value='Show Selection',uvalue='show selection',/frame)
qq = widget_button(control,value='Reset',uvalue='Reset',/frame)

;	a message window, for "useful" comments...
  txtwgt=WIDGET_TEXT(whole,xsize=30,ysize=3,/frame,/scroll)
  message = ['Ready for action...  make selection and hit "Show Selection"']
  WIDGET_CONTROL,txtwgt,set_value= message

  if wdebug then print,time1,' ** ',time2,' **'
  sttime = widget_base(whole,/row,/frame)

;	a window for changing the start time...
  hhoz = widget_base(sttime,/column,/frame)
  txt8 = widget_label(hhoz,value='Start Time')
  txt8 = widget_label(hhoz,value=time1)

;	a window for changing the stop time...
  hhoz = widget_base(sttime,/column,/frame)
  txt8 = widget_label(hhoz,value='Stop Time')
  txt8 = widget_label(hhoz,value=time2)

;
;		exposure time range; AEC
  hh = widget_base(whole,/row)
  hh3 = widget_base(hh,/row,/frame)

  hh3x = widget_base(hh3,/row,/frame)

;	a window for changing the minimum exposure
  txt8 = widget_label(hh3x,value='Exposure (s)  from')
  expmin=WIDGET_TEXT(hh3x,xsize=6,ysize=1,/editable)	;,/frame)
  WIDGET_CONTROL,expmin,set_value= ''
;	a window for changing the maximum exposure
  txt8 = widget_label(hh3x,value=' to ')
  expmax=WIDGET_TEXT(hh3x,xsize=8,ysize=1,/editable)	;,/frame)
  WIDGET_CONTROL,expmax,set_value= ''

;;  txt8 = widget_label(hh3,value='AEC')
;;  aecset=['AEC on','AEC off']
;;  txt8 = widget_droplist(hh3,value=aecset,uvalue='AEC')

;
;	TRACE channels and image dimensions
  gg = widget_base(whole,/row)

  gg2 = widget_base(gg,/column,/frame)
  value = 'TRACE Channels'
  txt8 = widget_label(gg2,value=value)
  uu = replicate(value,n_elements(w_wave))
  hchans = w_wave & hchan_vec = intarr(n_elements(hchans))
  xmenu,hchans,gg2,uvalue=uu,buttons=b4,/column,/nonexcl,/frame

  gg2 = widget_base(gg,/column,/frame)
  value = 'Image Dimension'
  txt8 = widget_label(gg2,value=value)
  uu = replicate(value,n_elements(w_nx))
  schans = ' nx ge '+string(w_nx,format='(i4)') & schan_vec = intarr(n_elements(schans))
  xmenu,schans,gg2,uvalue=uu,buttons=b2,/column,/excl,/frame


;>>>>>>>>>>> derive pointing?????
  gg2 = widget_base(gg,/column,/frame)
  value = 'TRACE Pointing????'
  txt8 = widget_label(gg2,value=value)


;>>		seperate widget window for listings
;???????	should this be selectable

  list_images = widget_base(title='List of Selected TRACE Images', $
	group_leader=whole,/column)

  message = trace_list_index(index)

  listwgt=WIDGET_TEXT(list_images,xsize=80,ysize=15,/frame,/scroll)
  WIDGET_CONTROL,listwgt,set_value= message


;	start it up...
widget_control,/realize,list_images
widget_control,/realize,whole

xmanager,'TRACE_SSWHERE',whole


return, dsets

end
